/*
 * Tapioca library
 * Copyright (C) 2005 INdT 
 * @author Andre Moreira Magalhaes <andre.magalhaes@indt.org.br>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __TAPIOCA_VIDEO_SESSION_PRIVATE_H__
#define __TAPIOCA_VIDEO_SESSION_PRIVATE_H__

#include "tapioca_video_session.h"

G_BEGIN_DECLS

/* dbus callbacks */
gboolean tapioca_video_session_accept                 (TapiocaVideoSession *tas,
                                                       GError **error);
gboolean tapioca_video_session_reject                 (TapiocaVideoSession *tas,
                                                       GError **error);
gboolean tapioca_video_session_set_local_capabilities (TapiocaVideoSession *tas,
                                                       const gchar *local_capabilities,
                                                       GError **error);
gboolean tapioca_video_session_get_capabilities       (TapiocaVideoSession *tas,
                                                       gchar **local_capabilities,
                                                       gchar **remote_capabilities,
                                                       GError **error);
gboolean tapioca_video_session_add_local_candidate    (TapiocaVideoSession *tas, 
                                                       const gchar *name,
                                                       const gchar *protocol,
                                                       const gchar *ip,
                                                       guint port,
                                                       gdouble preference,
                                                       const gchar *username,
                                                       const gchar *password,
                                                       const gchar *type,
                                                       guint generation,
                                                       GError **error);

/* workaround: remove the above functions when dbus works with child objects 
   calling parent objects methods/signals */
gboolean tapioca_video_session_initiate               (TapiocaVideoSession *tas,
                                                       GError **error);
gboolean tapioca_video_session_close                  (TapiocaVideoSession *tas,
                                                       GError **error);
gboolean tapioca_video_session_get_session_type       (TapiocaVideoSession *tas,
                                                       guint *session_type,
                                                       GError **error);
gboolean tapioca_video_session_get_members            (TapiocaVideoSession *tas,
                                                       gchar ***ids,
                                                       GError **error);
gboolean tapioca_video_session_add_members            (TapiocaVideoSession *tas,
                                                       const gchar **ids,
                                                       GError **error);
gboolean tapioca_video_session_remove_members         (TapiocaVideoSession *tas,
                                                       const gchar **ids,
                                                       GError **error);
gboolean tapioca_video_session_destroy                (TapiocaVideoSession *tas,
                                                       GError **error);

G_END_DECLS

#endif
